Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(72)

Unified Diff: src/codec/SkCodecPriv.h

Issue 1316233002: Style Change: NULL->nullptr (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: 2015-08-27 (Thursday) 10:25:06 EDT Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/codec/SkCodec.cpp ('k') | src/codec/SkCodec_libgif.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/codec/SkCodecPriv.h
diff --git a/src/codec/SkCodecPriv.h b/src/codec/SkCodecPriv.h
index 450457f630137c98b854be9f2ad8ad963f8c71d0..9a28cfdda1690df3268b02198930bd8db2144135 100644
--- a/src/codec/SkCodecPriv.h
+++ b/src/codec/SkCodecPriv.h
@@ -82,10 +82,10 @@ static bool conversion_possible(const SkImageInfo& dst, const SkImageInfo& src)
}
/*
* If there is a color table, get a pointer to the colors, otherwise return NULL
*/
static const SkPMColor* get_color_ptr(SkColorTable* colorTable) {
- return NULL != colorTable ? colorTable->readColors() : NULL;
+ return nullptr != colorTable ? colorTable->readColors() : nullptr;
}
/*
@@ -95,9 +95,9 @@ static const SkPMColor* get_color_ptr(SkColorTable* colorTable) {
static inline void copy_color_table(const SkImageInfo& dstInfo, SkColorTable* colorTable,
SkPMColor* inputColorPtr, int* inputColorCount) {
if (kIndex_8_SkColorType == dstInfo.colorType()) {
- SkASSERT(NULL != inputColorPtr);
- SkASSERT(NULL != inputColorCount);
- SkASSERT(NULL != colorTable);
+ SkASSERT(nullptr != inputColorPtr);
+ SkASSERT(nullptr != inputColorCount);
+ SkASSERT(nullptr != colorTable);
memcpy(inputColorPtr, colorTable->readColors(), *inputColorCount * 4);
}
}
@@ -82,10 +82,10 @@ static bool conversion_possible(const SkImageInfo& dst, const SkImageInfo& src)
}
/*
- * If there is a color table, get a pointer to the colors, otherwise return NULL
+ * If there is a color table, get a pointer to the colors, otherwise return nullptr
*/
static const SkPMColor* get_color_ptr(SkColorTable* colorTable) {
« no previous file with comments | « src/codec/SkCodec.cpp ('k') | src/codec/SkCodec_libgif.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698